﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.SymbolicExpressionTreeEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.Robocode {
  [StorableClass]
  public class ShotPowerTreeNode : SymbolicExpressionTreeTerminalNode {
    private double value;
    [Storable]
    public double Value {
      get { return value; }
      private set { this.value = value; }
    }

    [StorableConstructor]
    private ShotPowerTreeNode(bool deserializing) : base(deserializing) { }
    private ShotPowerTreeNode(ShotPowerTreeNode original, Cloner cloner)
      : base(original, cloner) {
      this.value = original.value;
    }

    public ShotPowerTreeNode()
      : base(new ShotPower()) {
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ShotPowerTreeNode(this, cloner);
    }

    public override bool HasLocalParameters {
      get { return true; }
    }

    public override void ResetLocalParameters(IRandom random) {
      value = (double)random.Next(1, 3);
    }
  }
}